CompressorOxide

Struct CompressorOxide 

pub struct CompressorOxide { /* private fields */ }
Main compression struct.

Implementations

Source

impl CompressorOxide

pub fn new(flags: u32) -> Self

Create a new CompressorOxide with the given flags.

Notes

This function may be changed to take different parameters in the future.

pub fn with_format_and_level( data_format: DataFormat, level: CompressionLevel, ) -> CompressorOxide

Create a new CompressorOxide with the given flags.

pub fn with_params( data_format: DataFormat, level: u8, strategy: CompressionStrategy, window_bits: u8, ) -> CompressorOxide

Create a new ’CompressorOxide with the current format, level, strategy and window bits

Level will is limited to 10, and window bits is clamped to 15

pub const fn adler32(&self) -> u32

Get the adler32 checksum of the currently encoded data.

pub const fn prev_return_status(&self) -> TDEFLStatus

Get the return status of the previous compress call with this compressor.

pub const fn flags(&self) -> i32

Get the raw compressor flags.

Notes

This function may be deprecated or changed in the future to use more rust-style flags.

pub const fn data_format(&self) -> DataFormat

Returns whether the compressor is wrapping the data in a zlib format or not.

pub fn reset(&mut self)

Reset the state of the compressor, keeping the same parameters.

This avoids re-allocating data.

pub fn set_compression_level(&mut self, level: CompressionLevel)

Set the compression level of the compressor.

Changing compression level after compression has started will likely result in failure.

Notes

The compression strategy will be reset to the default one when this is called.

If using the zlib wrapper, increasing the compression level to one that requires a higher window_bits value than the max set at initialization will fail and leave the compressor at the current level.

pub fn set_compression_level_raw(&mut self, level: u8)

Set the compression level of the compressor using an integer value.

Changing compression level after compression has started will likely result in failure.

Notes

The compression strategy will be reset to the default one when this is called.

If using the zlib wrapper, increasing the compression level to one that requires a higher window_bits value than the max set at initialization will fail and leave the compressor at the current level.

pub fn set_format_and_level(&mut self, data_format: DataFormat, level: u8)

Update the compression settings of the compressor.

Changing the DataFormat after compression has started will result in a corrupted stream.

Changing compression level after compression has started will likely result in failure.

Notes

This function mainly intended for setting the initial settings after e.g creating with default or after calling CompressorOxide::reset(), and behaviour may be changed to disallow calling it after starting compression in the future.

If using the zlib wrapper, increasing the compression level to one that requires a higher window_bits value than the max set at initialization will fail and leave the compressor at the current level.

pub const fn unwritten_bit_count(&self) -> u32

Check the number of unwritten bits after the last flush. After a NoSync flush it can be used to test whether the stream is aligned with a byte boundary.