Enum MZError

enum MZError

A list of miniz failed status codes.

These are emitted as the Err side of a MZResult in the StreamResult returned from [deflate::stream::deflate()] or [inflate::stream::inflate()].

Variants

ErrNo

Unused

Stream

General stream error.

See [inflate::stream::inflate()] docs for details of how it can occur there.

See [deflate::stream::deflate()] docs for how it can in principle occur there, though it's believed impossible in practice.

Data

Error in inflation; see [inflate::stream::inflate()] for details.

Not returned from [deflate::stream::deflate()].

Mem

Unused

Buf

Buffer-related error.

See the docs of [deflate::stream::deflate()] or [inflate::stream::inflate()] for details of when it would trigger in the one you're using.

Version

Unused

Param

Bad parameters.

This can be returned from [deflate::stream::deflate()] in the case of bad parameters. See [TDEFLStatus::BadParam][deflate::core::TDEFLStatus::BadParam].

Implementations

impl Clone for MZError

fn clone(self: &Self) -> MZError

impl Copy for MZError

impl Debug for MZError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for MZError

impl Freeze for MZError

impl Hash for MZError

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for MZError

fn eq(self: &Self, other: &MZError) -> bool

impl RefUnwindSafe for MZError

impl Send for MZError

impl StructuralPartialEq for MZError

impl Sync for MZError

impl Unpin for MZError

impl UnsafeUnpin for MZError

impl UnwindSafe for MZError

impl<T> Any for MZError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MZError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MZError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MZError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MZError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for MZError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for MZError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MZError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MZError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>