Enum MZStatus

enum MZStatus

A list of miniz successful status codes.

These are emitted as the Ok side of a MZResult in the StreamResult returned from [deflate::stream::deflate()] or [inflate::stream::inflate()].

Variants

Ok

Operation succeeded.

Some data was decompressed or compressed; see the byte counters in the StreamResult for details.

StreamEnd

Operation succeeded and end of deflate stream was found.

X-ref [TINFLStatus::Done][inflate::TINFLStatus::Done] or [TDEFLStatus::Done][deflate::core::TDEFLStatus::Done] for inflate or deflate respectively.

NeedDict

Unused

Implementations

impl Clone for MZStatus

fn clone(self: &Self) -> MZStatus

impl Copy for MZStatus

impl Debug for MZStatus

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for MZStatus

impl Freeze for MZStatus

impl Hash for MZStatus

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for MZStatus

fn eq(self: &Self, other: &MZStatus) -> bool

impl RefUnwindSafe for MZStatus

impl Send for MZStatus

impl StructuralPartialEq for MZStatus

impl Sync for MZStatus

impl Unpin for MZStatus

impl UnsafeUnpin for MZStatus

impl UnwindSafe for MZStatus

impl<T> Any for MZStatus

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MZStatus

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MZStatus

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MZStatus

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MZStatus

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for MZStatus

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for MZStatus

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MZStatus

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MZStatus

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>