Struct DecompressorOxide

struct DecompressorOxide { ... }

Main decompression struct.

Implementations

impl DecompressorOxide

fn new() -> DecompressorOxide

Create a new tinfl_decompressor with all fields set to 0.

fn init(self: &mut Self)

Set the current state to Start.

fn adler32(self: &Self) -> Option<u32>

Returns the adler32 checksum of the currently decompressed data. Note: Will return Some(1) if decompressing zlib but ignoring adler32.

fn adler32_header(self: &Self) -> Option<u32>

Returns the adler32 that was read from the zlib header if it exists.

impl Clone for DecompressorOxide

fn clone(self: &Self) -> DecompressorOxide

impl Default for DecompressorOxide

fn default() -> Self

Create a new tinfl_decompressor with all fields set to 0.

impl Freeze for DecompressorOxide

impl RefUnwindSafe for DecompressorOxide

impl Send for DecompressorOxide

impl Sync for DecompressorOxide

impl Unpin for DecompressorOxide

impl UnsafeUnpin for DecompressorOxide

impl UnwindSafe for DecompressorOxide

impl<T> Any for DecompressorOxide

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DecompressorOxide

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DecompressorOxide

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DecompressorOxide

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DecompressorOxide

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DecompressorOxide

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DecompressorOxide

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DecompressorOxide

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DecompressorOxide

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>