Enum TINFLStatus

enum TINFLStatus

Return status codes.

Variants

FailedCannotMakeProgress

More input data was expected, but the caller indicated that there was no more data, so the input stream is likely truncated.

This can't happen if you have provided the [TINFL_FLAG_HAS_MORE_INPUT][core::inflate_flags::TINFL_FLAG_HAS_MORE_INPUT] flag to the decompression. By setting that flag, you indicate more input exists but is not provided, and so reaching the end of the input data without finding the end of the compressed stream would instead return a [NeedsMoreInput][Self::NeedsMoreInput] status.

BadParam

The output buffer is an invalid size; consider the flags parameter.

Adler32Mismatch

The decompression went fine, but the adler32 checksum did not match the one provided in the header.

Failed

Failed to decompress due to invalid data.

Done

Finished decompression without issues.

This indicates the end of the compressed stream has been reached.

NeedsMoreInput

The decompressor needs more input data to continue decompressing.

This occurs when there's no more consumable input, but the end of the stream hasn't been reached, and you have supplied the [TINFL_FLAG_HAS_MORE_INPUT][core::inflate_flags::TINFL_FLAG_HAS_MORE_INPUT] flag to the decompressor. Had you not supplied that flag (which would mean you were asserting that you believed all the data was available) you would have gotten a [FailedCannotMakeProcess][Self::FailedCannotMakeProgress] instead.

HasMoreOutput

There is still pending data that didn't fit in the output buffer.

Implementations

impl TINFLStatus

fn from_i32(value: i32) -> Option<TINFLStatus>

impl Clone for TINFLStatus

fn clone(self: &Self) -> TINFLStatus

impl Copy for TINFLStatus

impl Debug for TINFLStatus

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for TINFLStatus

impl Freeze for TINFLStatus

impl Hash for TINFLStatus

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for TINFLStatus

fn eq(self: &Self, other: &TINFLStatus) -> bool

impl RefUnwindSafe for TINFLStatus

impl Send for TINFLStatus

impl StructuralPartialEq for TINFLStatus

impl Sync for TINFLStatus

impl Unpin for TINFLStatus

impl UnsafeUnpin for TINFLStatus

impl UnwindSafe for TINFLStatus

impl<T> Any for TINFLStatus

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TINFLStatus

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TINFLStatus

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TINFLStatus

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TINFLStatus

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for TINFLStatus

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TINFLStatus

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TINFLStatus

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TINFLStatus

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>