Struct MinReset

struct MinReset

Resets state, without performing expensive ops (e.g. zeroing buffer)

Note that not zeroing buffer can lead to security issues when dealing with untrusted input.

Implementations

impl Freeze for MinReset

impl RefUnwindSafe for MinReset

impl ResetPolicy for MinReset

fn reset(self: &Self, state: &mut InflateState)

impl Send for MinReset

impl Sync for MinReset

impl Unpin for MinReset

impl UnsafeUnpin for MinReset

impl UnwindSafe for MinReset

impl<T> Any for MinReset

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MinReset

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MinReset

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for MinReset

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for MinReset

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MinReset

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MinReset

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>