Struct StreamResult
struct StreamResult { ... }
A structure containing the result of a call to the inflate or deflate streaming functions.
Fields
bytes_consumed: usizeThe number of bytes consumed from the input slice.
bytes_written: usizeThe number of bytes written to the output slice.
status: MZResultThe return status of the call.
Implementations
impl StreamResult
const fn error(error: MZError) -> StreamResult
impl Clone for StreamResult
fn clone(self: &Self) -> StreamResult
impl Copy for StreamResult
impl Debug for StreamResult
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for StreamResult
impl Freeze for StreamResult
impl Hash for StreamResult
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for StreamResult
fn eq(self: &Self, other: &StreamResult) -> bool
impl RefUnwindSafe for StreamResult
impl Send for StreamResult
impl StructuralPartialEq for StreamResult
impl Sync for StreamResult
impl Unpin for StreamResult
impl UnsafeUnpin for StreamResult
impl UnwindSafe for StreamResult
impl<T> Any for StreamResult
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for StreamResult
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for StreamResult
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for StreamResult
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for StreamResult
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for StreamResult
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for StreamResult
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for StreamResult
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for StreamResult
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>