Type Alias MZResult
type MZResult = Result<MZStatus, MZError>
Result alias for all miniz status codes both successful and failed.
MZResulttype MZResult = Result<MZStatus, MZError>
Result alias for all miniz status codes both successful and failed.