Enum TDEFLFlush
enum TDEFLFlush
A list of deflate flush types.
Variants
-
None Normal operation.
Compress as much as there is space for, and then return waiting for more input.
-
Sync Try to flush all the current data and output an empty raw block.
-
Full Same as [
Sync][Self::Sync], but reset the dictionary so that the following data does not depend on previous data.-
Finish Try to flush everything and end the deflate stream.
On success this will yield a
TDEFLStatus::Donereturn status.
Implementations
impl TDEFLFlush
const fn new(flush: i32) -> Result<Self, MZError>
impl Clone for TDEFLFlush
fn clone(self: &Self) -> TDEFLFlush
impl Copy for TDEFLFlush
impl Debug for TDEFLFlush
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for TDEFLFlush
impl Freeze for TDEFLFlush
impl From for TDEFLFlush
fn from(flush: MZFlush) -> Self
impl Hash for TDEFLFlush
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for TDEFLFlush
fn eq(self: &Self, other: &TDEFLFlush) -> bool
impl RefUnwindSafe for TDEFLFlush
impl Send for TDEFLFlush
impl StructuralPartialEq for TDEFLFlush
impl Sync for TDEFLFlush
impl Unpin for TDEFLFlush
impl UnsafeUnpin for TDEFLFlush
impl UnwindSafe for TDEFLFlush
impl<T> Any for TDEFLFlush
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TDEFLFlush
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TDEFLFlush
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for TDEFLFlush
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for TDEFLFlush
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for TDEFLFlush
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for TDEFLFlush
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TDEFLFlush
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TDEFLFlush
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>