Function compress_to_output
fn compress_to_output<impl FnMut(&[u8]) -> bool: FnMut(&[u8]) -> bool>(d: &mut CompressorOxide, in_buf: &[u8], flush: TDEFLFlush, callback_func: impl FnMut(&[u8]) -> bool) -> (TDEFLStatus, usize)
Main compression function. Callbacks output.
Returns
Returns a tuple containing the current status of the compressor, the current position in the input buffer.
The caller is responsible for ensuring the CallbackFunc struct will not cause undefined
behaviour.