Function deflate

fn deflate(compressor: &mut CompressorOxide, input: &[u8], output: &mut [u8], flush: MZFlush) -> StreamResult

Try to compress from input to output with the given CompressorOxide.

Errors

Returns MZError::Buf If the size of the output slice is empty or no progress was made due to lack of expected input data, or if called without MZFlush::Finish after the compression was already finished.

Returns MZError::Param if the compressor parameters are set wrong.

Returns MZError::Stream when lower-level decompressor returns a TDEFLStatus::PutBufFailed; may not actually be possible.