Function decompress_slice_iter_to_slice

fn decompress_slice_iter_to_slice<'out, 'inp, impl Iterator<Item = &'inp [u8]>: Iterator<Item = &'inp [u8]>>(out: &'out mut [u8], it: impl Iterator<Item = &'inp [u8]>, zlib_header: bool, ignore_adler32: bool) -> Result<usize, TINFLStatus>

Decompress one or more source slices from an iterator into the output slice.

This will fail if the output buffer is not large enough, but in that case the output buffer will still contain the partial decompression.