Function decompress_to_vec_zlib
fn decompress_to_vec_zlib(input: &[u8]) -> Result<Vec<u8>, DecompressError>
Decompress the deflate-encoded data (with a zlib wrapper) in input to a vector.
NOTE: This function will not bound the output, so if the output is large enough it can result in an out of memory error. It is therefore suggested to not use this for anything other than test programs, use the functions with a specified limit, or ideally streaming decompression via the flate2 library instead.
Returns a Result containing the Vec of decompressed data on success, and a [struct][DecompressError] containing the status and so far decompressed data if any on failure.