Struct ZeroReset
struct ZeroReset
Resets state and zero memory, continuing to use the same data format.
Implementations
impl Freeze for ZeroReset
impl RefUnwindSafe for ZeroReset
impl ResetPolicy for ZeroReset
fn reset(self: &Self, state: &mut InflateState)
impl Send for ZeroReset
impl Sync for ZeroReset
impl Unpin for ZeroReset
impl UnsafeUnpin for ZeroReset
impl UnwindSafe for ZeroReset
impl<T> Any for ZeroReset
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ZeroReset
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ZeroReset
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ZeroReset
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ZeroReset
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ZeroReset
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ZeroReset
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>